translate.storage.omegat.OmegaTFileTab

Package translate :: Package storage :: Module omegat :: Class OmegaTFileTab |
[hide private]
[frames] | no frames]

# Class OmegaTFileTab

source code

An OmegT translation memory file in the default system encoding

Nested Classes | [hide private]
Inherited from `base.TranslationStore`: `UnitClass`

Instance Methods | [hide private]
_get_encoding(self) | source code
Inherited from `OmegaTFile`: `__init__`, `__str__`, `parse` Inherited from `base.TranslationStore`: `__getstate__`, `__setstate__`, `add_unit_to_index`, `addsourceunit`, `addunit`, `findid`, `findunit`, `findunits`, `getsourcelanguage`, `gettargetlanguage`, `getunits`, `isempty`, `makeindex`, `remove_unit_from_index`, `require_index`, `save`, `savefile`, `setsourcelanguage`, `settargetlanguage`, `translate`, `unit_iter` Inherited from `base.TranslationStore` (private): `_assignname` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `base.TranslationStore`: `parsefile`, `parsestring`

Class Variables | [hide private]
| Name = `None` The human usable name of this store type
| Mimetypes = `["application/x-omegat-glossary"]` A list of MIME types associated with this store type
| Extensions = ``[``'``tab``'``]`` A list of file extentions associated with this store type
Inherited from `base.TranslationStore`: `suggestions_in_format` Inherited from `base.TranslationStore` (private): `_binary`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### _get_encoding(self) | source code
Overrides: OmegaTFile._get_encoding